============
User Guide
============

The Units library user guide is an in depth look at how to use the C++ library and its functionality, covering the basic types in the library and operations with them.
The guide covers the basic types and what operations are available on them, as well as a lot of details on how to use the library.

The python package is a simplified wrapper around the C++ library and is discussed in :ref:`python`

.. toctree::
   :maxdepth: 1

   units
   measurements
   fixed_measurements
   uncertain_measurements
   from_string
   to_string
   math_operations
   commodities
   user_defined_units
   Physical_constants
   defined_units
   custom_units
   custom_count_units
   Unit_domains
   conversion_flags
   special_units
   equation_units
   python
